| MSCsimtester | R Documentation |
The package performs comparisons of certain summary statistics for simulated gene tree samples to
theoretical predictions under the multispecies coalescent model.
The primary functions are rootedTriple for comparison of frequencies of topological rooted triples
on gene trees, and pairwiseDist and ADtest for comparison of the distributions of pairwise
distances between taxa on gene trees.
Required input is a collection of gene trees, stored as a multiPhylo object by the ape package,
and a rooted species tree, as a Phylo object,
with edge lengths in generations, together with constant population sizes for each edge.
MSCsimtester builds on the packages ape and kSamples.
For further examples of use and citation purposes, see \insertRef2022allman-MSCsimtesterMSCsimtester.
Maintainer: Elizabeth Allman e.allman@alaska.edu [copyright holder]
Authors:
Hector Banos hbassnos@gmail.com [copyright holder]
John Rhodes j.rhodes@alaska.edu [copyright holder]
2022allman-MSCsimtesterMSCsimtester
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.