| plotEdgeOrder | R Documentation |
Under the MSC, each edge in the species tree must be assigned a population size. This function displays the species tree with the edges numbered, to aid the user in entering constant population sizes as an appropriately ordered list.
plotEdgeOrder(stree)
stree |
An object of class |
NONE
pairwiseDist, rootedTriple, plotPops
stree=read.tree(text="(((a:10000,b:10000):10000,c:20000):10000,d:30000);")
plotEdgeOrder(stree)
pops=c(30000,20000,1,1,1,1,10000)
plotPops(stree,pops)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.