| plotPops | R Documentation |
Plot species tree, with population sizes on edges.
plotPops(stree, populations)
stree |
An object of class |
populations |
A vector containing constant population sizes, one entry for each edge/population in the species tree, with last entry for the population ancestral to the root. |
NONE
pairwiseDist, rootedTriple, plotEdgeOrder
stree=read.tree(text="(((a:10000,b:10000):10000,c:20000):10000,d:30000);")
plotEdgeOrder(stree)
pops=c(30000,20000,1,1,1,1,10000)
plotPops(stree,pops)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.